@@ -193,7 +193,7 @@ class test_Hub:
         callback = Mock(name='callback')
         with patch.object(self.hub, '_ready_lock', autospec=True) as lock:
             self.hub.call_soon(callback)
-            assert lock.__enter__.called_once()
+            lock.__enter__.assert_called_once()
 
     def test_call_soon__promise_argument(self):
         callback = promise(Mock(name='callback'), (1, 2, 3))
@@ -568,4 +568,4 @@ class test_Hub:
     def test__pop_ready_uses_lock(self):
         with patch.object(self.hub, '_ready_lock', autospec=True) as lock:
             self.hub._pop_ready()
-            assert lock.__enter__.called_once()
+            lock.__enter__.assert_called_once()
